@@ -172,6 +172,12 @@ get_client_secret (GoaOAuth2Provider *oauth2_provider)
   return GOA_GOOGLE_CLIENT_SECRET;
 }
 
+static gboolean
+get_use_pkce (GoaOAuth2Provider *oauth2_provider)
+{
+  return TRUE;
+}
+
 /* ---------------------------------------------------------------------------------------------------- */
 
 static gchar *
@@ -427,5 +433,6 @@ goa_google_provider_class_init (GoaGoogleProviderClass *klass)
   oauth2_class->get_redirect_uri          = get_redirect_uri;
   oauth2_class->get_scope                 = get_scope;
   oauth2_class->get_token_uri             = get_token_uri;
+  oauth2_class->get_use_pkce              = get_use_pkce;
   oauth2_class->add_account_key_values    = add_account_key_values;
 }
