@@ -1051,7 +1051,6 @@ oauth2_secret_service_get_cb (GObject      *object,
   g_autoptr(GTask) task = G_TASK (g_steal_pointer (&user_data));
   GCancellable *cancellable = g_task_get_cancellable (task);
   g_autoptr(SecretService) service = NULL;
-  g_autolist (SecretCollection) collections = NULL;
   g_autoptr(GError) error = NULL;
 
   g_return_if_fail (G_IS_TASK (task));
@@ -1233,7 +1232,6 @@ goa_oauth2_provider_add_account (GoaProvider         *provider,
   g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, goa_oauth2_provider_add_account);
   g_task_set_task_data (task, data, account_data_free);
-  goa_provider_task_bind_window (task, GTK_WINDOW (data->dialog));
 
   create_account_details_ui (provider, data, TRUE);
   g_signal_connect_object (data->dialog,
@@ -1241,7 +1239,7 @@ goa_oauth2_provider_add_account (GoaProvider         *provider,
                            G_CALLBACK (oauth2_secret_run_task),
                            task,
                            0 /* G_CONNECT_DEFAULT */);
-  gtk_window_present (GTK_WINDOW (data->dialog));
+  goa_provider_task_run_in_dialog (task, data->dialog);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -1344,7 +1342,6 @@ goa_oauth2_provider_refresh_account (GoaProvider         *provider,
   g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, goa_oauth2_provider_refresh_account);
   g_task_set_task_data (task, data, account_data_free);
-  goa_provider_task_bind_window (task, GTK_WINDOW (data->dialog));
 
   create_account_details_ui (provider, data, FALSE);
   g_signal_connect_object (data->dialog,
@@ -1352,7 +1349,7 @@ goa_oauth2_provider_refresh_account (GoaProvider         *provider,
                            G_CALLBACK (oauth2_secret_run_task),
                            task,
                            0 /* G_CONNECT_DEFAULT */);
-  gtk_window_present (GTK_WINDOW (data->dialog));
+  goa_provider_task_run_in_dialog (task, data->dialog);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
